{


use "$path_data\Data\GlobalBPS_clean_combined.dta", clear // accesssed in June 2022; not sharable because it is maintained by the global unit and not yet publicly available 
keep country_code country_long wbes wbes unique_id wave cov0 cov0b cov6a size_t0 size_t1 size_t2 size_t3 size_t4 sales exporter change_sales status bps_period smooth_severity_crisis transit_m1
**# Merge isic codes
merge m:1 unique_id wave cov0 using "$path_data\Data\concordance to ISIC classification.dta" // not sharable due to connection to the BPS harmonized data file"
tab _m
drop _m
order size_t3, a(size_t2)
order size_t4, a(size_t3)
/* Drop observation with no country */
drop if missing(country_code)
/* Drop permanently closed establishments */
drop if status==3
/* Create quarter variable */
gen quarter 	= 1 if !missing(cov0) & (month(cov0) > 3 & year(cov0) == 2020) & (month(cov0) <= 6 & year(cov0) == 2020) 	// Apr-Jun 2020
replace quarter = 2 if !missing(cov0) & (month(cov0) > 6 & year(cov0) == 2020) & (month(cov0) <= 9 & year(cov0) == 2020) 	// Jul-Sep 2020
replace quarter = 3 if !missing(cov0) & (month(cov0) > 9 & year(cov0) == 2020) & (month(cov0) <= 12 & year(cov0) == 2020) 	// Oct-Dec 2020
replace quarter = 4 if !missing(cov0) & (month(cov0) >= 1 & year(cov0) == 2021) & (month(cov0) <= 3 & year(cov0) == 2021) 	// Jan-Mar 2021
replace quarter = 5 if !missing(cov0) & (month(cov0) > 3 & year(cov0) == 2021) & (month(cov0) <= 6 & year(cov0) == 2021) 	// Apr-Jun 2021
replace quarter = 6 if !missing(cov0) & (month(cov0) > 6 & year(cov0) == 2021) & (month(cov0) <= 9 & year(cov0) == 2021) 	// Jul-Sep 2021
replace quarter = 7 if !missing(cov0) & (month(cov0) > 9 & year(cov0) == 2021) & (month(cov0) <= 12 & year(cov0) == 2021) 	// Oct-Dec 2021
replace quarter = 8 if !missing(cov0) & (month(cov0) >= 1 & year(cov0) == 2022) & (month(cov0) <= 3 & year(cov0) == 2022) 	// Jan-Mar 2022
replace quarter = 9 if !missing(cov0) & (month(cov0) >= 3 & year(cov0) == 2022) & (month(cov0) <= 6 & year(cov0) == 2022) 	// Apr-Jun 2022
label define quarter 1 "Apr-Jun 2020" 2 "Jul-Sep 2020" 3 "Oct-Dec 2020" 4 "Jan-Mar 2021" 5 "Apr-Jun 2021" 6 "Jul-Sep 2021" 7 "Oct-Dec 2021" 8 "Jan-Mar 2022" 9 "Apr-Jun 2022"
label values quarter quarter
order quarter, a(cov0)
/* Create year variable */
gen year = year(cov0)
order year, a(quarter)
/* Create 2-digits ISIC codes */
replace isic4 = "" if isic4=="0" 			// Umatched codes
gen isic2 = substr(isic4, 1, 2)
order isic2, a(isic4)
/* Create numeric variables for 2-digits and 4-digits ISIC, and country codes */
destring isic2, gen(num_isic2)
order num_isic2, a(isic2)
destring isic4, gen(num_isic4)
order num_isic4, a(isic4)
encode country_code, gen(iso)
order iso, a(country_long)
drop if bps_period > wave & bps_period != .
/* Create number of workers */
gen workers = .
forvalues wave = 1(1)4 {
    replace workers = size_t`wave' if wave == `wave'
}
*
replace workers = size_t0 if workers == . & wave == 1
forvalues j=0/4 {
    replace workers = size_t`j' if missing(workers)
}
*
gen log_size = ln(workers + 1)
order workers, a(size_t4)
order log_size, a(workers)
/* Drop if missing number of workers */
drop if missing(log_size)
/* Create numeric id */
egen float num_id = group(unique_id)
order num_id, a(unique_id)
/* Create new subsector variables */
/*
BPS:
1 = Agriculture, fishing, or mining
2 = Manufacturing
3= Construction or utilities //
4= Retail or Wholesale
5= Transportation and storage //
6= Accommodation 
7= Food services
8 = Information and communication
9= Financial activities or real state
10= Education 
11= Health 
12=Other services
*/
cap drop dummy
gen dummy = 1 if num_isic2 >= 1 & num_isic2 <= 9 
replace dummy = 2 if num_isic2 >= 10 & num_isic2 <= 33 			// Manufacturing
replace dummy = 3 if num_isic2 >= 35 & num_isic2 <= 43
replace dummy = 4 if num_isic2 >= 45 & num_isic2 <= 47
replace dummy = 5 if num_isic2 >= 49 & num_isic2 <= 53
replace dummy = 6 if num_isic2 == 55 | (num_isic2 >= 90 & num_isic2 <= 93)
replace dummy = 7 if num_isic2 == 56
replace dummy = 8 if num_isic2 >= 58 & num_isic2 <= 63
replace dummy = 9 if num_isic2 >= 64 & num_isic2 <= 68
replace dummy = 10 if num_isic2 == 85 
replace dummy = 11 if num_isic2 >= 86 & num_isic2 <= 88
replace dummy = 12 if (num_isic2 >= 69 & num_isic2 <= 82) | (num_isic2 >= 94 & num_isic2 != .)
rename dummy subsector
order subsector, a(num_isic2)
/* Drop health and education sectors */
drop if subsector==10 | subsector==11
drop if num_isic2==35 | num_isic2==36 | num_isic2==38
/* Big subsectors */
recode subsector /*
*/ (1 = 1 "Agro and mining") /*
*/ (2 = 2 "Manufacturing") /*
*/ (3 = 3 "Const. and utilities") /*
*/ (4 = 4 "Retail and wholesale") /*
*/ (nonmiss = 5 "Services"), /*
*/ gen(subsector2)
order subsector2, a(subsector)
/* Merge alternative sector classification */
preserve
	import excel "$path_data\Data\sector_categories.xlsx", sheet("Sheet1") firstrow clear
	drop Description2
	rename isic2 num_isic2
	tempfile temp
	save `temp'
restore
merge m:1 num_isic2 using `temp'
drop if _merge==2
drop _merge
rename categ subsector3
sencode subsector3, replace
order subsector3, a(subsector2)
/* Create new variables for looping samples */
gen sample_all = 1
label variable sample_all "Full sample"
gen sample_manuf = (subsector2==2)
label variable sample_manuf "Manufacturing"
gen sample_serv = (subsector2==5)
label variable sample_serv "Services (without retail and construction)"
gen sample_servPlus = (subsector2==3 | subsector2==4 | subsector2==5)
label variable sample_servPlus "Services (including retail and construction)"
gen sample_knowIntense = (subsector3==10)
label variable sample_knowIntense "Knowledge intensive services"
gen sample_retail = (subsector3==8)
label variable sample_retail "Retail"
gen sample_hospitality = (subsector3==9)
label variable sample_hospitality "Hospitality"
/* Create dummy variable for country-waves with at least 100 observations */
gen dummy = 1
bysort quarter isic2: egen num_obs = total(dummy)
replace num_obs = 0 if num_obs < 100
replace num_obs = 1 if num_obs >= 100 & num_obs != .
rename num_obs use_isic2
drop dummy
label var use_isic2 "country-waves with at least 100 observations"

**# Merge country internet variables */
merge m:1 country_code using "$path_data\Data\Internet_usage.dta"
drop if _merge==2
drop _merge
merge m:1 country_code using "$path_data\Data\Secure_servers.dta"
drop if _merge==2
drop _merge
label var indiv_internet "Individuals using the Internet (% of population)"
label var secure_internet "Secure Internet servers (per 1 million people)"

**# Create dummies for above/below the median of country indicators */
/*
	indiv_internetnew: Individuals using the Internet (% of population) (0-100)
	secure_internet: 	Secure Internet servers (per 1 million people) (0-80,000)
*/
preserve
	global list_indicators_country indiv_internet secure_internet 
	keep country_code ${list_indicators_country}
	drop if missing(country_code)
	duplicates drop
	label define dummy_median_country /*
	*/ 0 "Below the country median" /*
	*/ 1 "Above the country median", replace
	foreach var of global list_indicators_country {
		local short_var_name = substr("`var'", 1, 20)
		egen 	country_med_`short_var_name' 	= xtile(`var'), nq(2)
		replace country_med_`short_var_name' 	= country_med_`short_var_name' - 1 			// So that variable is 0,1 instead of 1,2
		label values country_med_`short_var_name' dummy_median_country
		local lab_var: variable label `var'
		label var country_med_`short_var_name' "`lab_var'"
		/* Create z-score of variables */
		summ `var'
		gen `short_var_name'_zs = (`var' - `r(mean)') / `r(sd)'	
		local lab_var: variable label `var'
		local lab_var = "`lab_var'" + " (z-score)"
		label var `short_var_name'_zs "`lab_var'"
	}
	*
	keep country_code country_med_* *_zs
	tempfile temp
	save `temp'
restore

merge m:1 country_code using `temp'
drop _merge

rename indiv_internet country_ct_indiv_internet
rename indiv_internet_zs country_zs_indiv_internet
rename secure_internet country_ct_secure_internet
rename secure_internet_zs country_zs_secure_internet
order country_ct_secure_internet, a(country_zs_indiv_internet)

**# Merge sector remote labor variables 
preserve
tempfile temp
use "$path_data\Data\remote_labor_isic.dta", clear
collapse remote_labor_index [w=tot_emp], by( ISIC40 )
rename ISIC40 isicr4
rename remote_labor_index remote_labor_int_4d_isic_o
gen isicr4_2=substr(isicr4,1,2)
save `temp', replace
use "$path_data\Data\remote_labor_isic.dta", clear
gen isicr4_2=substr(ISIC40,1,2)
collapse remote_labor_index [w=tot_emp], by( isicr4_2 )
rename remote_labor_index remote_labor_int_2d_isic_o
merge 1:m isicr4_2 using `temp'
tab _m
drop _m
order isicr4 remote_labor_int_4d_isic_o remote_labor_int_2d_isic_o
order isicr4 isicr4_2
drop isicr4_2
order isicr4 remote_labor_int_4d_isic remote_labor_int_2d_isic
rename isicr4 isic4
save `temp', replace

restore
merge m:1 isic4 using `temp'
tab _m
drop if _m==2
drop _m

/* Fill in the missing values for remote_labor_2d_o */
rename remote_labor_int_2d_isic_o remote_labor_2d_o
rename remote_labor_int_4d_isic_o remote_labor_4d_o
egen a=mode(remote_labor_2d_o), by(isic2)
drop remote_labor_2d_o
rename a remote_labor_2d_o
order remote_labor_2d_o, b(remote_labor_4d_o)
label var  remote_labor_2d_o "Remote work feasibility, two dig."
label var  remote_labor_4d_o "Remote work feasibility, four dig."

**# Create dummies for above/below the median of sector indicators */
/*
	remote_labor_int_2d_o 	Share of remote workers (2 digits)
	remote_labor_int_4d_o 	Share of remote workers (4 digits)
*/
	
preserve
	global list_indicators_sector remote_labor_2d_o remote_labor_4d_o 


	keep isic4 ${list_indicators_sector}
	drop if missing(isic4)
	
	label var remote_labor_2d_o "Share of remote workers (2 digits)" 
	label var remote_labor_4d_o "Share of remote workers (4 digits)"
	
	duplicates drop

	label define dummy_median_sector /*
	*/ 0 "Below the sector median" /*
	*/ 1 "Above the sector median", replace

	foreach var of global list_indicators_sector {
	    local short_var_name = substr("`var'", 1, 20)
		
		egen 	sector_med_`short_var_name' = xtile(`var'), nq(2)
		replace sector_med_`short_var_name' = sector_med_`short_var_name' - 1
		label values sector_med_`short_var_name' dummy_median_sector
		
		local lab_var: variable label `var'
		label var sector_med_`short_var_name' "`lab_var'"
		/* Create z-score of variables */
		summ `var'
		gen `short_var_name'_zs = (`var' - `r(mean)') / `r(sd)'	
		local lab_var: variable label `var'
		local lab_var = "`lab_var'" + " (z-score)"
		label var `short_var_name'_zs "`lab_var'"
	}
	*
	
	keep isic4 sector_med_* *_zs
	tempfile temp
	save `temp'
restore

merge m:1 isic4 using `temp'
drop _merge

rename remote_labor_2d_o sector_ct_remote_labor_2d_o
order sector_ct_remote_labor_2d_o, b(sector_med_remote_labor_2d_o)
rename remote_labor_2d_o_zs sector_zs_remote_labor_2d_o
rename remote_labor_4d_o sector_ct_remote_labor_4d_o
order sector_ct_remote_labor_4d_o, b(sector_med_remote_labor_4d_o)
rename remote_labor_4d_o_zs sector_zs_remote_labor_4d_o

drop if missing(isic)

save "$path_data\dataset.dta", replace
}


