
	**# Figures 1
{
use dataset, clear
keep if wave == 3
keep isic isic4 change_sales sector_ct_remote_labor_2d_o sector_ct_remote_labor_4d_o country_ct_indiv_internet country_ct_secure_internet country_med_indiv_internet country_med_secure_internet country_long
gen isic2 = substr(isic, 1, 2)
tabstat country_ct_indiv_internet country_ct_secure_internet, statistics(count mean SD p25 p75 p95 p5)
///top 5
keep if country_ct_indiv_internet>=88.3
collapse (mean) change_sales sector_ct_remote_labor_2d_o, by(isic2)
label var change_sales "Change in sales"
label var sector_ct_remote_labor_2d_o "Remote labor intensity"
//drop some outliers
keep if -20<change_sales & 20>change_sales
drop if sector_ct_remote_labor_2d_o>=0.5
graph twoway (scatter change_sales sector_ct_remote_labor_2d_o, msize(1pt)) (qfit change_sales sector_ct_remote_labor_2d_o)
gr export "new_isic2_top5.png", replace
}

	**# Figures 2
{
use dataset, clear
keep if wave == 3
keep isic isic4 change_sales sector_ct_remote_labor_2d_o sector_ct_remote_labor_4d_o country_ct_indiv_internet country_ct_secure_internet country_med_indiv_internet country_med_secure_internet country_long
gen isic2 = substr(isic, 1, 2)
tabstat country_ct_indiv_internet country_ct_secure_internet, statistics(count mean SD p25 p75 p95 p5)
///bottom 5
keep if country_ct_indiv_internet<21.96
collapse (mean) change_sales sector_ct_remote_labor_2d_o, by(isic2)
drop if isic2=="0"
label var change_sales "Change in sales"
label var sector_ct_remote_labor_2d_o "Remote labor intensity"
drop if sector_ct_remote_labor_2d_o>=0.6
graph twoway (scatter change_sales sector_ct_remote_labor_2d_o, msize(1pt)) (qfit change_sales sector_ct_remote_labor_2d_o)
gr export "new_isic2_bottom5.png", replace
}
	
	

	**# Table 1 baseline
			{
	use dataset, clear
	rename num_id num_id
	gen one=1
	egen sample_panel=sum(one), by(num_id)
	replace sample_panel=2 if sample_panel>=2
	drop if quarter>=7	
	bys country_code: egen tot=sum(one)
	gen weight=1/tot	// weights by country	
	
	global controls_reg "log_size i.quarter transit_m1" 
	global controls_reg_tt "log_size transit_m1"
	svyset [pweight=weight]
	
	estimates clear
	macro drop _all 

	global controls_reg "log_size i.quarter transit_m1"
	
	quietly svy: reg change_sales i.sector_med_remote_labor_2d_o##i.country_med_indiv_internet##i.exporter ${controls_reg}
	generate sample = e(sample)

					svy: reg change_sales c.country_zs_indiv_internet#c.sector_zs_remote_labor_2d_o ${controls_reg} ///
					i.iso i.num_isic2 if sample == 1
					
					svy: reg change_sales c.country_zs_indiv_internet#c.sector_zs_remote_labor_2d_o ${controls_reg} ///
					i.iso i.num_isic2 if exporter == 1 & sample == 1
					estimates store est_exp
	
					svy: reg change_sales c.country_zs_indiv_internet#c.sector_zs_remote_labor_2d_o ${controls_reg} ///
					i.iso i.num_isic2 if exporter == 0 & sample == 1
					estimates store est_non_exp

					qui suest _all	
					test [est_non_exp]c.country_zs_indiv_internet#c.sector_zs_remote_labor_2d_o=[est_exp]c.country_zs_indiv_internet#c.sector_zs_remote_labor_2d_o
					global F_C: display %4.3f `r(F)'
					display "$F_C"

					svy: reg change_sales c.sector_zs_remote_labor_2d_o#c.country_zs_indiv_internet##i.exporter ${controls_reg} ///
					i.iso i.num_isic2 if sample == 1  
	}
	

 	**# Table 2 Panel A Alternative Internet measure
{
	use dataset, clear
	rename num_id num_id
	gen one=1
	egen sample_panel=sum(one), by(num_id)
	replace sample_panel=2 if sample_panel>=2
	drop if quarter>=7	
	bys country_code: egen tot=sum(one)
	gen weight=1/tot	// weights by country	
	
	global controls_reg "log_size i.quarter transit_m1" 
	global controls_reg_tt "log_size transit_m1"
	svyset [pweight=weight]
	
	estimates clear
	macro drop _all 
	
	
	global controls_reg "log_size i.quarter transit_m1" 
	
		quietly svy: reg change_sales i.sector_med_remote_labor_2d_o##i.country_med_secure_internet##i.exporter ${controls_reg}
		generate sample = e(sample)
		
					svy: reg change_sales c.country_zs_secure_internet#c.sector_zs_remote_labor_2d_o ${controls_reg} ///
					i.iso i.num_isic2 if sample == 1
					
					svy: reg change_sales c.country_zs_secure_internet#c.sector_zs_remote_labor_2d_o ${controls_reg} ///
					i.iso i.num_isic2 if exporter == 1 & sample == 1		
					estimates store est_exp
		
					svy: reg change_sales c.country_zs_secure_internet#c.sector_zs_remote_labor_2d_o ${controls_reg} ///
					i.iso i.num_isic2 if exporter == 0 & sample == 1		
					estimates store est_non_exp
		
					qui suest _all		
					test [est_non_exp]c.country_zs_secure_internet#c.sector_zs_remote_labor_2d_o= [est_exp]c.country_zs_secure_internet#c.sector_zs_remote_labor_2d_o
					global F_C	: display %4.3f `r(F)'	
					display "$F_C"
					
					svy: reg change_sales c.sector_zs_remote_labor_2d_o#c.country_zs_secure_internet##i.exporter ${controls_reg} ///
					i.iso i.num_isic2 if sample == 1 
}


 	**# Table 2 Panel B Alternative: 4 digit defined remote work
{
	use dataset, clear
	gen one=1
	egen sample_panel=sum(one), by(num_id)
	replace sample_panel=2 if sample_panel>=2
	drop if quarter>=7	
	bys country_code: egen tot=sum(one)
	gen weight=1/tot	// weights by country	
	
	global controls_reg "log_size i.quarter transit_m1" 
	global controls_reg_tt "log_size transit_m1"
	svyset [pweight=weight]
	
	estimates clear
	macro drop _all 
	
	global controls_reg "log_size i.quarter transit_m1"
	
		quietly svy: reg change_sales i.sector_med_remote_labor_2d_o##i.country_med_indiv_internet##i.exporter ${controls_reg}
		generate sample = e(sample)
	
		* Testing whether the baseline works with 4-digit remote work indicator
		
				svy: reg change_sales c.country_zs_indiv_internet#c.sector_med_remote_labor_4d_o ${controls_reg} ///
					i.iso i.num_isic2 if sample == 1
					
				svy: reg change_sales c.country_zs_indiv_internet#c.sector_med_remote_labor_4d_o ${controls_reg} ///
					i.iso i.num_isic2 if exporter == 1 & sample == 1
				estimates store est_exp

				svy: reg change_sales c.country_zs_indiv_internet#c.sector_med_remote_labor_4d_o ${controls_reg} ///
					i.iso i.num_isic2 if exporter == 0 & sample == 1
				estimates store est_non_exp
				
		qui suest _all		
		test [est_non_exp]c.country_zs_indiv_internet#c.sector_med_remote_labor_4d_o= ///
			[est_exp]c.country_zs_indiv_internet#c.sector_med_remote_labor_4d_o
		global F_C	: display %4.3f `r(F)'
		display "$F_C"
		
		svy: reg change_sales c.sector_med_remote_labor_4d_o#c.country_zs_indiv_internet##i.exporter ${controls_reg} ///
			i.iso i.num_isic2 if sample == 1		
}

 	
	 **# Table 3 Panel A robustness: ommitted variable bias
	{
	use dataset, clear
	gen one=1
	egen sample_panel=sum(one), by(num_id)
	replace sample_panel=2 if sample_panel>=2
	drop if quarter>=7	
	bys country_code: egen tot=sum(one)
	gen weight=1/tot	// weights by country	
	
	global controls_reg "log_size i.quarter transit_m1" 
	global controls_reg_tt "log_size transit_m1"
	svyset [pweight=weight]
	
	estimates clear
	macro drop _all 
	
		bys country_code isic4: egen cov6a_sc = mean(cov6a)
		gen l_cov6a_sc = log(cov6a_sc)
		drop cov6a_sc
		rename l_cov6a_sc cov6a_sc
		
		estimates clear
		macro drop _all 
	
	global controls_reg "log_size cov6a_sc i.quarter transit_m1"

		
		quietly svy: reg change_sales i.sector_med_remote_labor_2d_o##i.country_med_indiv_internet##i.exporter ${controls_reg}
		generate sample = e(sample)
	
				svy: reg change_sales c.country_zs_indiv_internet#c.sector_zs_remote_labor_2d_o ${controls_reg} ///
					i.iso i.num_isic2 if sample == 1
					
				svy: reg change_sales c.country_zs_indiv_internet#c.sector_zs_remote_labor_2d_o ${controls_reg} ///
					i.iso i.num_isic2 if exporter == 1 & sample == 1
				estimates store est_exp
				
				svy: reg change_sales c.country_zs_indiv_internet#c.sector_zs_remote_labor_2d_o ${controls_reg} ///
					i.iso i.num_isic2 if exporter == 0 & sample == 1
				estimates store est_non_exp
				
		qui suest _all		
		test [est_non_exp]c.country_zs_indiv_internet#c.sector_zs_remote_labor_2d_o= ///
			[est_exp]c.country_zs_indiv_internet#c.sector_zs_remote_labor_2d_o
		global F_C	: display %4.3f `r(F)'				
		display "$F_C"
		
			svy: reg change_sales c.sector_zs_remote_labor_2d_o#c.country_zs_indiv_internet##i.exporter ${controls_reg} ///
				i.iso i.num_isic2 if sample == 1  		
	}
	
	
	
	**# Table 3 Panel B robustness: human capital
	{
	use dataset, clear
	gen one=1
	egen sample_panel=sum(one), by(num_id)
	replace sample_panel=2 if sample_panel>=2
	drop if quarter>=7	
	bys country_code: egen tot=sum(one)
	gen weight=1/tot	// weights by country	
	
	global controls_reg "log_size i.quarter transit_m1" 
	global controls_reg_tt "log_size transit_m1"
	svyset [pweight=weight]
	
	estimates clear
	macro drop _all 

		*Barro-Lee: Average years of total schooling, age 25+, total

	preserve
	import excel "Data\R_Data_Extract_From_Education_Statistics_Education_Attainment.xlsx", sheet("stata") firstrow clear
	drop if country_code == ""
	tempfile education
	save `education', replace
	restore
		
	merge m:1 country_code using `education', nogen
		
	estimates clear
	macro drop _all 	

	global controls_reg "log_size c.education_years#c.sector_zs_remote_labor_2d_o i.quarter transit_m1"

		
		quietly svy: reg change_sales i.sector_med_remote_labor_2d_o##i.country_med_indiv_internet##i.exporter ${controls_reg}
		generate sample = e(sample)

					svy: reg change_sales c.country_zs_indiv_internet#c.sector_zs_remote_labor_2d_o ${controls_reg} ///
					i.iso i.num_isic2 if sample == 1
		
					svy: reg change_sales c.country_zs_indiv_internet#c.sector_zs_remote_labor_2d_o ${controls_reg} ///
					i.iso i.num_isic2 if exporter == 1 & sample == 1
					estimates store est_exp

					svy: reg change_sales c.country_zs_indiv_internet#c.sector_zs_remote_labor_2d_o ${controls_reg} ///
					i.iso i.num_isic2 if exporter == 0 & sample == 1
					estimates store est_non_exp
					
					qui suest _all		
					test [est_non_exp]c.country_zs_indiv_internet#c.sector_zs_remote_labor_2d_o= ///
					[est_exp]c.country_zs_indiv_internet#c.sector_zs_remote_labor_2d_o
					global F_C	: display %4.3f `r(F)'					
					display "$F_C"
					
					svy: reg change_sales c.sector_zs_remote_labor_2d_o#c.country_zs_indiv_internet##i.exporter ${controls_reg} ///
					i.iso i.num_isic2 if sample == 1  
	}
	
	
	
	**# Table 3 Panel C robustness: digitalization
	{
	use dataset, clear
	gen one=1
	egen sample_panel=sum(one), by(num_id)
	replace sample_panel=2 if sample_panel>=2
	drop if quarter>=7	
	bys country_code: egen tot=sum(one)
	gen weight=1/tot	// weights by country	
	
	global controls_reg "log_size i.quarter transit_m1" 
	global controls_reg_tt "log_size transit_m1"
	svyset [pweight=weight]
	
	estimates clear
	macro drop _all 

	
		* GDP per capita
		
		preserve
		import excel "Data\API_NY.GDP.PCAP.KD_DS2.xlsx", sheet("stata") firstrow clear
		drop if country_code == ""
		tempfile gdp_pc
		save `gdp_pc', replace
		restore
		
		merge m:1 country_code using `gdp_pc', nogen
		
		gen l_gdp_pc = log(gdp_pc)
		
		estimates clear
		macro drop _all 


	global controls_reg "log_size c.l_gdp_pc#c.sector_zs_remote_labor_2d_o i.quarter transit_m1"

	
		quietly svy: reg change_sales i.sector_med_remote_labor_2d_o##i.country_med_indiv_internet##i.exporter ${controls_reg}
		generate sample = e(sample)
	
				svy: reg change_sales c.country_zs_indiv_internet#c.sector_zs_remote_labor_2d_o ${controls_reg} ///
					i.iso i.num_isic2 if sample == 1
					
				svy: reg change_sales c.country_zs_indiv_internet#c.sector_zs_remote_labor_2d_o ${controls_reg} ///
					i.iso i.num_isic2 if exporter == 1 & sample == 1
				estimates store est_exp
				
				svy: reg change_sales c.country_zs_indiv_internet#c.sector_zs_remote_labor_2d_o ${controls_reg} ///
					i.iso i.num_isic2 if exporter == 0 & sample == 1
				estimates store est_non_exp
				
		qui suest _all		
		test [est_non_exp]c.country_zs_indiv_internet#c.sector_zs_remote_labor_2d_o= ///
			[est_exp]c.country_zs_indiv_internet#c.sector_zs_remote_labor_2d_o
		global F_C	: display %4.3f `r(F)'
		display "$F_C"
		
		
			svy: reg change_sales c.sector_zs_remote_labor_2d_o#c.country_zs_indiv_internet##i.exporter ${controls_reg} ///
				i.iso i.num_isic2 if sample == 1  			
}	
	


	**# Table 4 Panel A Heterogeneity: manufacturing
	{
	use dataset, clear
	gen one=1
	egen sample_panel=sum(one), by(num_id)
	replace sample_panel=2 if sample_panel>=2
	drop if quarter>=7	
	bys country_code: egen tot=sum(one)
	gen weight=1/tot	// weights by country	
	
	global controls_reg "log_size i.quarter transit_m1" 
	global controls_reg_tt "log_size transit_m1"
	svyset [pweight=weight]
	
	estimates clear
	macro drop _all 
	
	
	global controls_reg "log_size i.quarter transit_m1"

		quietly svy: reg change_sales i.sector_med_remote_labor_2d_o##i.country_med_indiv_internet##i.exporter ${controls_reg} ///
				if sample_manuf==1 
		generate sample = e(sample)
		
					svy: reg change_sales c.country_zs_indiv_internet#c.sector_zs_remote_labor_2d_o ${controls_reg} ///
					i.iso i.num_isic2 if sample == 1
				
					svy: reg change_sales c.country_zs_indiv_internet#c.sector_zs_remote_labor_2d_o ${controls_reg} ///
					i.iso i.num_isic2 if exporter == 1 & sample == 1
					estimates store est_exp	
					
					svy: reg change_sales c.country_zs_indiv_internet#c.sector_zs_remote_labor_2d_o ${controls_reg} ///
					i.iso i.num_isic2 if exporter == 0 & sample == 1
					estimates store est_non_exp		
					
					qui suest _all		
					test [est_non_exp]c.country_zs_indiv_internet#c.sector_zs_remote_labor_2d_o= [est_exp]c.country_zs_indiv_internet#c.sector_zs_remote_labor_2d_o
					global F_C	: display %4.3f `r(F)'	
					display "$F_C"
					
					svy: reg change_sales c.sector_zs_remote_labor_2d_o#c.country_zs_indiv_internet##i.exporter ${controls_reg} ///
					i.iso i.num_isic2 if sample == 1  		
}


	**# Table 4 Panel B Heterogeneity: services
{
	use dataset, clear
	gen one=1
	egen sample_panel=sum(one), by(num_id)
	replace sample_panel=2 if sample_panel>=2
	drop if quarter>=7	
	bys country_code: egen tot=sum(one)
	gen weight=1/tot	// weights by country	
	
	global controls_reg "log_size i.quarter transit_m1" 
	global controls_reg_tt "log_size transit_m1"
	svyset [pweight=weight]
	
	estimates clear
	macro drop _all 

	global controls_reg "log_size i.quarter transit_m1" 

		quietly svy: reg change_sales i.sector_med_remote_labor_2d_o##i.country_med_indiv_internet##i.exporter ${controls_reg} ///
				if sample_servPlus==1&sample_hospitality~=1
		generate sample = e(sample)
		
					svy: reg change_sales c.country_zs_indiv_internet#c.sector_zs_remote_labor_2d_o ${controls_reg} ///
					i.iso i.num_isic2 if sample == 1
		
					svy: reg change_sales c.country_zs_indiv_internet#c.sector_zs_remote_labor_2d_o ${controls_reg} ///
					i.iso i.num_isic2 if exporter == 1 & sample == 1
					estimates store est_exp	
					
					svy: reg change_sales c.country_zs_indiv_internet#c.sector_zs_remote_labor_2d_o ${controls_reg} ///
					i.iso i.num_isic2 if exporter == 0 & sample == 1
					estimates store est_non_exp		
					
					qui suest _all		
					test [est_non_exp]c.country_zs_indiv_internet#c.sector_zs_remote_labor_2d_o= ///
					[est_exp]c.country_zs_indiv_internet#c.sector_zs_remote_labor_2d_o
					global F_C	: display %4.3f `r(F)'					
					display "$F_C"

					svy: reg change_sales c.sector_zs_remote_labor_2d_o#c.country_zs_indiv_internet##i.exporter ${controls_reg} ///
					i.iso i.num_isic2 if sample == 1  	
	
}
	
	
	**# Table 5 Heterogeneity: time effects
	{
	use dataset, clear
	gen one=1
	egen sample_panel=sum(one), by(num_id)
	replace sample_panel=2 if sample_panel>=2
	drop if quarter>=7	
	bys country_code: egen tot=sum(one)
	gen weight=1/tot	// weights by country	
	
	global controls_reg "log_size i.quarter transit_m1" 
	global controls_reg_tt "log_size transit_m1"
	svyset [pweight=weight]
	
	estimates clear
	macro drop _all 
	
	*********************************
	
	
	gen quarter_mod = quarter
	replace quarter_mod = 3 if quarter == 4
	replace quarter_mod = 4 if quarter == 5
	replace quarter_mod = 4 if quarter == 6
	rename quarter quarter_orig
	rename quarter_mod quarter
	estimates clear
	macro drop _all 
	
	
					svy: reg change_sales c.country_zs_indiv_internet#c.sector_zs_remote_labor_2d_o#i.quarter ${controls_reg_tt} ///
					i.iso i.wbes if quarter <= 7 & use_isic2==1 & exporter != .	// use_isic2 filters country-quarters with more than 100 observations
					
					svy: reg change_sales c.country_zs_indiv_internet#c.sector_zs_remote_labor_2d_o#i.quarter ${controls_reg_tt} ///
					i.iso i.wbes if quarter <= 7 & use_isic2==1 & exporter == 1					
					
					svy: reg change_sales c.country_zs_indiv_internet#c.sector_zs_remote_labor_2d_o#i.quarter ${controls_reg_tt} ///
					i.iso i.wbes if quarter <= 7 & use_isic2==1 & exporter == 0 					

					svy: reg change_sales c.country_zs_secure_internet#c.sector_zs_remote_labor_2d_o#i.quarter ${controls_reg_tt} ///
					i.iso i.wbes if quarter <= 7 & use_isic2==1 & exporter != .	// use_isic2 filters country-quarters with more than 100 observations

					svy: reg change_sales c.country_zs_secure_internet#c.sector_zs_remote_labor_2d_o#i.quarter ${controls_reg_tt} ///
					i.iso i.wbes if quarter <= 7 & use_isic2==1 & exporter == 1
	
					svy: reg change_sales c.country_zs_secure_internet#c.sector_zs_remote_labor_2d_o#i.quarter ${controls_reg_tt} ///
					i.iso i.wbes if quarter <= 7 & use_isic2==1 & exporter == 0 
}	
	
	
	
	**# Table A1
{
	use dataset, clear
	gen one=1
	egen sample_panel=sum(one), by(num_id)
	replace sample_panel=2 if sample_panel>=2
	drop if quarter>=7	
	bys country_code: egen tot=sum(one)
	gen weight=1/tot	// weights by country	
	
	global controls_reg "log_size i.quarter transit_m1" 
	global controls_reg_tt "log_size transit_m1"
	svyset [pweight=weight]

		* Descriptive statistics *
		quietly svy: reg change_sales i.sector_med_remote_labor_2d_o##i.country_med_indiv_internet##i.exporter ${controls_reg}
		generate sample = e(sample)
		keep if sample==1
		keep country_code country_long unique_id
		duplicates drop
		tab country_long
}


	
**# Table A2
{
	use dataset, clear
	gen one=1
	egen sample_panel=sum(one), by(num_id)
	replace sample_panel=2 if sample_panel>=2
	drop if quarter>=7	
	bys country_code: egen tot=sum(one)
	gen weight=1/tot	// weights by country	
	
	global controls_reg "log_size i.quarter transit_m1" 
	global controls_reg_tt "log_size transit_m1"
	svyset [pweight=weight]	
	
		* Descriptive statistics *
		quietly svy: reg change_sales i.sector_med_remote_labor_2d_o##i.country_med_indiv_internet##i.exporter ${controls_reg}
		generate sample = e(sample)	

	keep if sample==1
	gen subsector4=1 if inlist(subsector2,1)
	replace subsector4=2 if subsector2==2
	replace subsector4=3 if subsector3==9
	replace subsector4=4 if subsector2==4
	replace subsector4=5 if subsector3==10
	replace subsector4=6 if subsector4==.
	drop subsector
	rename subsector4 subsector
	label define subsectorlbl 1 "Agriculture/mining" 2 "Manufacturing" 3 "Hospitality" 4 "Retail/wholesale" 5 "Knowledge intensive services" 6 "Other services"
	label values subsector subsectorlbl
	keep country_code unique_id wave exporter change_sales workers subsector
	
	preserve
	gen a=wave
	egen b=max(a), by( country_code unique_id)
	sort unique_id wave
	keep if b==a
	qui bys  country_code unique_id: gen check=_N
	*## Number of firms
	tab check
	drop check
	restore
	
	gen size_new=1 if workers<=19
	replace size_new=2 if workers>=20&workers<=99
	replace size_new=3 if workers>=100
	qui tab size_new, gen(d)
	qui tab subsector, gen(s)
	
	foreach var in d1 d2 d3 s1 s2 s3 s4 s5 s6 {
	gen `var'_exp=`var'
	replace `var'_exp=. if `var'==0
	replace `var'_exp=`var'_exp*exporter
	}
	
	**# Change in sales and exporter
	sum change_sales exporter d1 d2 d3 s1 s2 s3 s4 s5 s6
	**# Share of exporters by type of firm
	sum d1_exp d2_exp d3_exp s1_exp s2_exp s3_exp s4_exp s5_exp s6_exp
 
}


**# Table A3
{
	use dataset, clear
	gen one=1
	egen sample_panel=sum(one), by(num_id)
	replace sample_panel=2 if sample_panel>=2
	drop if quarter>=7	
	bys country_code: egen tot=sum(one)
	gen weight=1/tot	// weights by country	
	
	global controls_reg "log_size i.quarter transit_m1" 
	global controls_reg_tt "log_size transit_m1"
	svyset [pweight=weight]

		* Descriptive statistics *
		quietly svy: reg change_sales i.sector_med_remote_labor_2d_o##i.country_med_indiv_internet##i.exporter ${controls_reg}
		generate sample = e(sample)	
		tabstat sector_ct_remote_labor_2d_o if sample == 1, stat(N mean sd min median max) by(isic2) format(%9.2f) 

}
		
**# Table A4		
{	
	use dataset, clear
	gen one=1
	egen sample_panel=sum(one), by(num_id)
	replace sample_panel=2 if sample_panel>=2
	drop if quarter>=7	
	bys country_code: egen tot=sum(one)
	gen weight=1/tot	// weights by country	
	
	global controls_reg "log_size i.quarter transit_m1" 
	global controls_reg_tt "log_size transit_m1"
	svyset [pweight=weight]

		* Descriptive statistics *
		quietly svy: reg change_sales i.sector_med_remote_labor_2d_o##i.country_med_indiv_internet##i.exporter ${controls_reg}
		generate sample = e(sample)
		tabstat country_ct_indiv_internet if sample == 1, stat(N mean sd min median max) by(country_long) format(%9.2f) 
		tabstat country_ct_secure_internet if sample == 1, stat(N mean sd min median max) by(country_long) format(%9.0f) 	
}
	
	

	
	
	
